==> nifi-1.28.1-source-release.zip: nifi-1.28.1/nifi-mock/src/main/java/org/apache/nifi/util/MockSessionFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.util;

import org.apache.nifi.components.state.StateManager;
import org.apache.nifi.processor.ProcessSession;
import org.apache.nifi.processor.ProcessSessionFactory;
import org.apache.nifi.processor.Processor;

import java.util.Collections;
import java.util.Set;
import java.util.concurrent.CopyOnWriteArraySet;

public class MockSessionFactory implements ProcessSessionFactory {

    private final Processor processor;
    private final SharedSessionState sharedState;
    private final Set<MockProcessSession> createdSessions = new CopyOnWriteArraySet<>();
    private final boolean enforceReadStreamsClosed;
    private final StateManager stateManager;
    private final boolean allowSynchronousSessionCommits;

    MockSessionFactory(final SharedSessionState sharedState, final Processor processor, final boolean enforceReadStreamsClosed, final StateManager stateManager,
                       final boolean allowSynchronousSessionCommits) {
        this.sharedState = sharedState;
        this.processor = processor;
        this.enforceReadStreamsClosed = enforceReadStreamsClosed;
        this.stateManager = stateManager;
        this.allowSynchronousSessionCommits = allowSynchronousSessionCommits;
    }

    @Override
    public ProcessSession createSession() {
        final MockProcessSession session = new MockProcessSession(sharedState, processor, enforceReadStreamsClosed, stateManager, allowSynchronousSessionCommits);
        createdSessions.add(session);
        return session;
    }

    public Set<MockProcessSession> getCreatedSessions() {
        return Collections.unmodifiableSet(createdSessions);
    }
}

==> nifi-2.3.0-source-release.zip: nifi-2.3.0/nifi-mock/src/main/java/org/apache/nifi/util/MockSessionFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.util;

import org.apache.nifi.components.state.StateManager;
import org.apache.nifi.processor.ProcessSession;
import org.apache.nifi.processor.ProcessSessionFactory;
import org.apache.nifi.processor.Processor;

import java.util.Collections;
import java.util.Set;
import java.util.concurrent.CopyOnWriteArraySet;

public class MockSessionFactory implements ProcessSessionFactory {

    private final Processor processor;
    private final SharedSessionState sharedState;
    private final Set<MockProcessSession> createdSessions = new CopyOnWriteArraySet<>();
    private final boolean enforceReadStreamsClosed;
    private final StateManager stateManager;
    private final boolean allowSynchronousSessionCommits;
    private final boolean allowRecursiveReads;

    MockSessionFactory(final SharedSessionState sharedState, final Processor processor, final boolean enforceReadStreamsClosed, final StateManager stateManager,
                       final boolean allowSynchronousSessionCommits, final boolean allowRecursiveReads) {
        this.sharedState = sharedState;
        this.processor = processor;
        this.enforceReadStreamsClosed = enforceReadStreamsClosed;
        this.stateManager = stateManager;
        this.allowSynchronousSessionCommits = allowSynchronousSessionCommits;
        this.allowRecursiveReads = allowRecursiveReads;
    }

    @Override
    public ProcessSession createSession() {
        final MockProcessSession session = new MockProcessSession(sharedState, processor, enforceReadStreamsClosed, stateManager, allowSynchronousSessionCommits, allowRecursiveReads);
        createdSessions.add(session);
        return session;
    }

    public Set<MockProcessSession> getCreatedSessions() {
        return Collections.unmodifiableSet(createdSessions);
    }
}
